@@ -87,7 +87,9 @@ typedef enum {
 	E_WEBDAV_RESOURCE_KIND_CALENDAR,
 	E_WEBDAV_RESOURCE_KIND_PRINCIPAL,
 	E_WEBDAV_RESOURCE_KIND_COLLECTION,
-	E_WEBDAV_RESOURCE_KIND_RESOURCE
+	E_WEBDAV_RESOURCE_KIND_RESOURCE,
+	E_WEBDAV_RESOURCE_KIND_SUBSCRIBED_ICALENDAR,
+	E_WEBDAV_RESOURCE_KIND_WEBDAV_NOTES
 } EWebDAVResourceKind;
 
 typedef enum {
@@ -98,7 +100,8 @@ typedef enum {
 	E_WEBDAV_RESOURCE_SUPPORTS_TASKS	= 1 << 3,
 	E_WEBDAV_RESOURCE_SUPPORTS_FREEBUSY	= 1 << 4,
 	E_WEBDAV_RESOURCE_SUPPORTS_TIMEZONE	= 1 << 5,
-	E_WEBDAV_RESOURCE_SUPPORTS_LAST		= E_WEBDAV_RESOURCE_SUPPORTS_TIMEZONE
+	E_WEBDAV_RESOURCE_SUPPORTS_WEBDAV_NOTES	= 1 << 6,
+	E_WEBDAV_RESOURCE_SUPPORTS_LAST		= E_WEBDAV_RESOURCE_SUPPORTS_WEBDAV_NOTES
 } EWebDAVResourceSupports;
 
 typedef struct _EWebDAVResource {
@@ -143,14 +146,15 @@ typedef enum {
 	E_WEBDAV_LIST_CREATION_DATE	= 1 << 5,
 	E_WEBDAV_LIST_LAST_MODIFIED	= 1 << 6,
 	E_WEBDAV_LIST_DESCRIPTION	= 1 << 7,
-	E_WEBDAV_LIST_COLOR		= 1 << 8
+	E_WEBDAV_LIST_COLOR		= 1 << 8,
+	E_WEBDAV_LIST_ONLY_CALENDAR	= 1 << 9,
+	E_WEBDAV_LIST_ONLY_ADDRESSBOOK	= 1 << 10
 } EWebDAVListFlags;
 
 /**
  * EWebDAVPropstatTraverseFunc:
  * @webdav: an #EWebDAVSession
- * @xpath_ctx: an #xmlXPathContextPtr
- * @xpath_prop_prefix: (nullable): an XPath prefix for the current prop element, without trailing forward slash
+ * @prop_node: an #xmlNode
  * @request_uri: a #SoupURI, containing the request URI, maybe redirected by the server
  * @href: (nullable): a full URI to which the property belongs, or %NULL, when not found
  * @status_code: an HTTP status code for this property
@@ -160,18 +164,15 @@ typedef enum {
  * e_webdav_session_report_sync() and other XML response with DAV:propstat
  * elements traversal functions.
  *
- * The @xpath_prop_prefix can be %NULL only once, for the first time,
- * which is meant to let the caller setup the @xpath_ctx, like to register
- * its own namespaces to it with e_xml_xpath_context_register_namespaces().
- * All other invocations of the function will have @xpath_prop_prefix non-%NULL.
+ * The @prop_node points to the actual property (prop) node and it can be examined
+ * with e_xml_find_child(), e_xml_find_children_nodes() and other provided XML helper functions.
  *
  * Returns: %TRUE to continue traversal of the returned response, %FALSE otherwise.
  *
  * Since: 3.26
  **/
 typedef gboolean (* EWebDAVPropstatTraverseFunc)	(EWebDAVSession *webdav,
-							 xmlXPathContext *xpath_ctx,
-							 const gchar *xpath_prop_prefix,
+							 xmlNode *prop_node,
 							 const SoupURI *request_uri,
 							 const gchar *href,
 							 guint status_code,
@@ -335,6 +336,9 @@ struct _EWebDAVSessionClass {
 GType		e_webdav_session_get_type		(void) G_GNUC_CONST;
 
 EWebDAVSession *e_webdav_session_new			(ESource *source);
+const gchar *	e_webdav_session_get_last_dav_error_code(EWebDAVSession *webdav);
+gboolean	e_webdav_session_get_last_dav_error_is_permission
+							(EWebDAVSession *webdav);
 SoupRequestHTTP *
 		e_webdav_session_new_request		(EWebDAVSession *webdav,
 							 const gchar *method,
